/****************************************************************************
* 	Do-File for the replication of											*
* 	Refugees Unwelcome? Changes in the Public Acceptance of Immigrants		*
*	and Refugees in Germany in the Course of Europe's "Immigration Crisis"	*
*																			*
* 	Authors: Christian S. Czymara und 										*
* 		     Alexander W. Schmidt-Catran									*
* 	Date:    August, 10th, 2017												*
*****************************************************************************


	OUR DATA SET CAN BE USED FOR SECONDARY DATA ANALYSIS, TEACHING 
	OR ANY OTHER PURPOSE FOR FREE. PLEASE CITE OUR PAPER(S) IF YOU DO SO:

	Czymara, Christian and Schmidt-Catran, Alexander W. (XXXX): Refugees Unwelcome? Changes in the Public Acceptance of Immigrants and Refugees
	in Germany in the Course of Europe's "Immigration Crisis". XXXXXXXXXXX, XX(X), pp. XXX. 
	
	Czymara, Christian. and Schmidt-Catran, Alexander W. (2016): Wer ist in Deutschland willkommen? Eine Vignettenanalyse zur Akzeptanz von Einwanderern. 
	Kölner Zeitschrift für Soziologie und Sozialpsychologie, 68(2), pp. 193-227.



*****************************************
	Notes: This do-file needs an ado. 
	Make sure it is installed:
	ssc install coefplot
*****************************************/


clear
set more off
capture log close
log using Czymara_SchmidtCatran_ESR.log, replace

* Load data
use czymara_schmidtcatran_esr.dta

* globals for immigrant profile variables
global VIG "ib0.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion"

* globals for respondent variables
global RES "ib0.res_gender ib4.res_empl i.res_educ_cat ib3.res_religious_denom c.res_age ib0.res_eastgerman ib4.res_migr_friends"



****************
* Descriptives *
****************

* Descriptive statistics of respondent and immigrant profiles characteristics (Table A1)
sum $VIG
bys id_res: gen help = _n
sum $RES if help == 1
drop help

* Factor correlations (Table OA1 in online appendix)
tab vig_reason, gen(vig_reason_d)
tab vig_religion, gen(vig_rel_d)
tab vig_origin, gen(vig_origin_d)
corr vig_gender vig_reason_d1 vig_reason_d2 vig_reason_d3 vig_rel_d1 vig_rel_d2 vig_rel_d3 ///
vig_origin_d1 vig_origin_d2 vig_origin_d3 vig_qualific vig_language

drop vig_reason_d1 vig_reason_d2 vig_reason_d3 vig_rel_d1 vig_rel_d2 vig_rel_d3 ///
vig_origin_d1 vig_origin_d2 vig_origin_d3


* Distribution of outcome (Figure 2)
sum vig_rating_live if t == 0
	local a = round(r(mean), .01)
sum vig_rating_live if t == 1
	local b = round(r(mean), .01)
hist vig_rating_live if t == 0, discrete percent scheme(s1mono) xscale(range(1(1)8)) xlabel(1(1)7) ///
	title("Wave 1 (Apr 2015)", span) ytitle("Percent") name(dist_t0, replace) xline(`a') xline(`b', lcolor(gray) lpattern(shortdash)) xscale(off) ///
	plotr(m(zero) lpattern(blank)) ylabel(, notick) addlabels addlabopts(yvarformat(%4.2f) mlabp(6) mlabc(white)) ///
	text(35 5.6 "`a'") text(35 4.4 "`b'", c(gs11))
hist vig_rating_live if t == 1, discrete percent scheme(s1mono) xscale(range(1(1)8)) xlabel(1(1)7) ///
	xtitle("") title("Wave 2 (Feb 2016)", span) ytitle("Percent") name(dist_t1, replace) xline(`a', lcolor(gray) lpattern(shortdash)) xline(`b') ///
	plotr(m(zero) lpattern(blank)) ylabel(, notick) addlabels addlabopts(yvarformat(%4.2f) mlabp(6) mlabc(white)) xtitle(Acceptance of immigrant profiles) ///
	text(35 5.6 "`a'", c(gs11)) text(35 4.4 "`b'")
graph combine dist_t0 dist_t1, col(1) name(dist_combined, replace)  scheme(s1mono) ycommon xcommon plotr(m(zero) lpattern(blank))

***************
* Analysis    *	
***************

* Empty Model (M0)
mixed vig_rating_live 					|| id_res: || t:	, mle var 
	est store m0

* Adding t and immigrant characteristics (M1)
mixed vig_rating_live i.t	$VIG 			|| id_res: || t:	, mle var
	est store m1
	lrtest m0

* Adding interactions between t and immigrant characteristics (M2)
mixed vig_rating_live	i.t##($VIG) 		|| id_res: || t:	, mle var
	est store m2
	lrtest m1

* Adding respondent characteristics (M3)
mixed vig_rating_live	i.t##($VIG) $RES	 || id_res: || t:	, mle var
	est store m3
	lrtest m2

* Adding three-way interaction betweeen t, immigrant characteristics and respondent's gender (M4)
mixed vig_rating_live	i.t##($VIG)##$RES 	|| id_res: || t:	, mle var
	est store m4
	lrtest m3
	
	* Get marginal effects of immigrant characteristics conditional on t and respondent's gender
	margins res_gender, dydx($VIG) over(t) post
	margins, coeflegend
	est store m4_marg
	
	* Test for signficant change between waves in the effects of immigrant characteristics  (reported in the text not in a table)
	* Immigrant's gender
		* Respondent: woman
		dis  _b[1.vig_gender:1.t#0bn.res_gender] - _b[1.vig_gender:0bn.t#0bn.res_gender]  // change in coefficients of immigrant's gender from wave 1 to wave 2
		test _b[1.vig_gender:0bn.t#0bn.res_gender] = _b[1.vig_gender:1.t#0bn.res_gender]  // change significant?
		* Respondent: man
		dis  _b[1.vig_gender:1.t#1.res_gender] - _b[1.vig_gender:0bn.t#1.res_gender]
		test _b[1.vig_gender:0bn.t#1.res_gender] = _b[1.vig_gender:1.t#1.res_gender]		
	* Immigrant's origin country = Lebanon
		* Respondent: woman
		dis  _b[0.vig_origin:1.t#0bn.res_gender] - _b[0.vig_origin:0bn.t#0bn.res_gender]
		test _b[0.vig_origin:0bn.t#0bn.res_gender] = _b[0.vig_origin:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[0.vig_origin:1.t#1.res_gender] - _b[0.vig_origin:0bn.t#1.res_gender]
		test _b[0.vig_origin:0bn.t#1.res_gender] = _b[0.vig_origin:1.t#1.res_gender]
	* Immigrant's origin country = Kenya
		* Respondent: woman
		dis  _b[2.vig_origin:1.t#0bn.res_gender] - _b[2.vig_origin:0bn.t#0bn.res_gender]
		test _b[2.vig_origin:0bn.t#0bn.res_gender] = _b[2.vig_origin:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[2.vig_origin:1.t#1.res_gender] - _b[2.vig_origin:0bn.t#1.res_gender]
		test _b[2.vig_origin:0bn.t#1.res_gender] = _b[2.vig_origin:1.t#1.res_gender]
	* Immigrant's reason for immigration = persecution
		* Respondent: woman
		dis  _b[1.vig_reason:1.t#0bn.res_gender] -  _b[1.vig_reason:0bn.t#0bn.res_gender]
		test _b[1.vig_reason:0bn.t#0bn.res_gender] = _b[1.vig_reason:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[1.vig_reason:1.t#1.res_gender] - _b[1.vig_reason:0bn.t#1.res_gender]
		test _b[1.vig_reason:0bn.t#1.res_gender] = _b[1.vig_reason:1.t#1.res_gender]
	* Immigrant's reason for immigration = job
		* Respondent: woman
		dis  _b[2.vig_reason:1.t#0bn.res_gender] - _b[2.vig_reason:0bn.t#0bn.res_gender]
		test _b[2.vig_reason:0bn.t#0bn.res_gender] = _b[2.vig_reason:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[2.vig_reason:1.t#1.res_gender] - _b[2.vig_reason:0bn.t#1.res_gender]
		test _b[2.vig_reason:0bn.t#1.res_gender] = _b[2.vig_reason:1.t#1.res_gender]	
	* Immigrant's religion = christian
		* Respondent: woman
		dis  _b[1.vig_religion:1.t#0bn.res_gender] - _b[1.vig_religion:0bn.t#0bn.res_gender]
		test _b[1.vig_religion:0bn.t#0bn.res_gender] = _b[1.vig_religion:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[1.vig_religion:1.t#1.res_gender] -  _b[1.vig_religion:0bn.t#1.res_gender]
		test _b[1.vig_religion:0bn.t#1.res_gender] = _b[1.vig_religion:1.t#1.res_gender]
	* Immigrant's religion = muslim
		* Respondent: woman
		dis  _b[2.vig_religion:1.t#0bn.res_gender] - _b[2.vig_religion:0bn.t#0bn.res_gender] 
		test _b[2.vig_religion:0bn.t#0bn.res_gender] = _b[2.vig_religion:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[2.vig_religion:1.t#1.res_gender] - _b[2.vig_religion:0bn.t#1.res_gender]
		test _b[2.vig_religion:0bn.t#1.res_gender] = _b[2.vig_religion:1.t#1.res_gender]	


* Table A3
est tab m1 m2 m3 m4, stats(n ll)
est tab m1 m2 m3 m4, star	




**********
* Graphs *
**********


** Plot model M2 (Figure 3)
estimates restore m2
coefplot (m2)  ///
	, ytick(, nogrid) drop(_cons) xline(0, lcolor(black)) msymbol(circle) scale(0.75) aspect(0.95) yscale(lcolor(none)) ///
	yline(2.5, lcolor(gs14)) yline(4.5, lcolor(gs14)) yline(7.5, lcolor(gs14)) yline(10.5, lcolor(gs14)) ///
	yline(12.5, lcolor(gs14)) yline(14.5, lcolor(gs14)) yline(17.9, lcolor(gs14)) yline(18.1, lcolor(gs14)) ///
	yline(20.5, lcolor(gs14)) yline(23.5, lcolor(gs14)) ///
	yline(26.5, lcolor(gs14)) yline(28.5, lcolor(gs14)) yline(30.5, lcolor(gs14)) ///
	xline(-.5) ///
	 scheme(s1mono) ///
		keep(1.t 1.vig_gender 0.vig_origin 2.vig_origin 1.vig_reason 2.vig_reason ///
	1.vig_qualific1 1.vig_language 1.vig_religion 2.vig_religion ///
	1.t#1.vig_gender 1.t#0.vig_origin 1.t#2.vig_origin 1.t#1.vig_reason 1.t#2.vig_reason ///
	1.t#1.vig_qualific1 1.t#1.vig_language 1.t#1.vig_religion 1.t#2.vig_religion) ///
		coeflabels(1.t = "t=1" 1.vig_gender = "man" 0.vig_origin = "Libanon" 2.vig_origin = "Kenia" ///
	1.vig_reason = "persecution" 2.vig_reason = "work"  ///
	1.vig_qualific1 = "high" 1.vig_language = "good" 1.vig_religion = "Christ" ///
	2.vig_religion = "Muslim" 1.t#1.vig_gender = "man" 1.t#0.vig_origin = "Libanon" 1.t#2.vig_origin = "Kenia" ///
	1.t#1.vig_reason = "persecution" 1.t#2.vig_reason = "work"  ///
	1.t#1.vig_qualific1 = "high" 1.t#1.vig_language = "good" 1.t#1.vig_religion = "Christ" ///
	1.t#2.vig_religion = "Muslim", labgap(-159) notick) ///
		headings(1.t = "{it:Wave (ref.: t=0)}" 1.vig_gender = "{it:Gender (ref.: woman)}" 0.vig_origin = "{it:Origin (ref.: France)}" ///
	1.vig_reason = "{it:Reason (ref.: better life)}" 1.vig_qualific1 = "{it:Qualification (ref.: low)}" ///
	1.vig_language = "{it:Language skills (ref.: low)}" 1.vig_religion = "{it:Religion (ref.: none)}" ///
	1.t#1.vig_gender = "{it:Gender (ref.: woman)}" 1.t#0.vig_origin = "{it:Origin (ref.: France)}" ///
	1.t#1.vig_reason = "{it:Reason (ref.: better life)}" 1.t#1.vig_qualific1 = "{it:Qualification (ref.: low)}" ///
	1.t#1.vig_language = "{it:Language skills (ref.: low)}" 1.t#1.vig_religion = "{it:Religion (ref.: none)}" , labgap(-164) nogap) ///
		groups(headroom 1.t 1.vig_gender 0.vig_origin 2.vig_origin 1.vig_reason 2.vig_reason ///
	1.vig_qualific1 1.vig_language 1.vig_religion 2.vig_religion = "{bf:  Main Effects}" ///
	1.t#1.vig_gender 1.t#0.vig_origin 1.t#2.vig_origin 1.t#1.vig_reason 1.t#2.vig_reason ///
	1.t#1.vig_qualific1 1.t#1.vig_language 1.t#1.vig_religion 1.t#2.vig_religion = "{bf:  Interactions (X t)}",  labgap(-51) labsize(medlarge)) ///
	name(coefficients, replace) plotr(m(zero) lpattern(blank)) graphregion(margin(l=10 r=-40)) yscale(alt)


** Three-way interactions, selected immigrant characteristics X respondent's gender X t based on model M4
* Immigrant's gender (Figure 4 a)
estimates restore m4
	margins, dydx(vig_gender) over(res_gender) at(t = 0) post
		est store m4_3wayint_t0_gender

estimates restore m4
	margins, dydx(vig_gender) over(res_gender) at(t = 1) post
		est store m4_3wayint_t1_gender

coefplot (m4_3wayint_t0_gender, label("Before event (t=0)")) (m4_3wayint_t1_gender, label("After event (t=1)")) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle)  ///
	title("{bf:a)} Marginal effects of male immigrant profiles (ref.: female)", span  size(medsmall)) ///
	 scheme(s1mono) ///
	coeflabels(, notick) ///
	groups(headroom 0.res_gender 1.res_gender = "Respondent's gender") ///
	name(threeway_int_gender, replace) plotr(m(zero) lpattern(blank)) legend(off)

* Immigrant's origin (Figure 4 b)
estimates restore m4
	margins, dydx(vig_origin) at(res_gender = 0 t = 0) post // female before
		est store m4_3wayint_origin_f_b

estimates restore m4
	margins, dydx(vig_origin) at(res_gender = 0 t = 1) post // female after
		est store m4_3wayint_origin_f_a

estimates restore m4
	margins, dydx(vig_origin) at(res_gender = 1 t = 0) post // male before
		est store m4_3wayint_origin_m_b

estimates restore m4
	margins, dydx(vig_origin) at(res_gender = 1 t = 1) post // male after
		est store m4_3wayint_origin_m_a

coefplot (m4_3wayint_origin_f_b) (m4_3wayint_origin_f_a) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle) scheme(s1mono) ///
	yline(2.5, lcolor(gs14)) coeflabels(, notick) ///
	groups(headroom 0.vig_origin 2.vig_origin = "Female respondents") 	///
	name(threeway_int_origin_female, replace) xscale(off) legend(off) plotr(m(zero) lpattern(blank))

coefplot (m4_3wayint_origin_m_b, label("Before event (t=0)")) (m4_3wayint_origin_m_a, label("After event (t=1)")) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle) scheme(s1mono) ///
	yline(0.5, lcolor(gs14)) coeflabels(, notick) ///
	groups(headroom 0.vig_origin 2.vig_origin = "Male respondents") ///
	name(threeway_int_origin_male, replace) plotr(m(zero) lpattern(blank)) legend(off)

graph combine threeway_int_origin_female threeway_int_origin_male, title("{bf:b)} Marginal effects of immigrant profile's origin (ref.: France)", span size(medsmall)) ///
	 scheme(s1mono) xcommon col(1) imargin(t=0.9 b=0.9) iscale(1)

* Immigrant's reason for migration (Figure 4 c)
estimates restore m4
	margins, dydx(vig_reason) at(res_gender = 0 t = 0) post // female before
		est store m4_3wayint_reason_f_b

estimates restore m4
	margins, dydx(vig_reason) at(res_gender = 0 t = 1) post // female after
		est store m4_3wayint_reason_f_a

estimates restore m4
	margins, dydx(vig_reason) at(res_gender = 1 t = 0) post // male before
		est store m4_3wayint_reason_m_b

estimates restore m4
	margins, dydx(vig_reason) at(res_gender = 1 t = 1) post // male after
		est store m4_3wayint_reason_m_a

coefplot (m4_3wayint_reason_f_b, label("Before event (t=0)")) (m4_3wayint_reason_f_a, label("After event (t=1)")) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle) scheme(s1mono) ///
	yline(2.5, lcolor(gs14)) coeflabels(1.vig_reason = "Political persecution" 2.vig_reason = "Prospective job", notick) ///
	groups(headroom 1.vig_reason 2.vig_reason = "Female respondents") 	///
	name(threeway_int_reason_female, replace) xscale(off) legend(off) plotr(m(zero) lpattern(blank)) legend(off)

coefplot (m4_3wayint_reason_m_b, label("Wave 1 (t=0)")) (m4_3wayint_reason_m_a, label("Wave 2 (t=1)")) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle) scheme(s1mono) ///
	yline(0.5, lcolor(gs14)) coeflabels(1.vig_reason = "Political persecution" 2.vig_reason = "Prospective job", notick) ///
	groups(headroom 1.vig_reason 2.vig_reason = "Male respondents") ///
	name(threeway_int_reason_male, replace) plotr(m(zero) lpattern(blank)) 

graph combine threeway_int_reason_female threeway_int_reason_male, title("{bf:c)} Marginal effects of immigrant profile's reason of migration (ref.: better life)", span size(medsmall)) ///
	 scheme(s1mono) xcommon col(1) imargin(t=0.9 b=0.9) iscale(1)

	 
* Test whether weights are needed 
*(compare DuMouchel, W. H. and Duncan, G. J. (1983). Using sample survey weights in multiple regression analyses of stratified samples, Journal of the American Statistical Association, 78, 535-543.)
	

* Model M1
mixed vig_rating_live (i.t $VIG)##c.weight 									|| id_res: 					 || t:  , mle var
	lrtest m1	
	
	* Weighted Modell
	mixed vig_rating_live i.t	$VIG 										|| id_res: , pweight(weight) || t:  , mle var
	est store m1_w		
	
	
* Model M2
mixed vig_rating_live	(i.t##($VIG))##c.weight 							|| id_res: , 				 || t:  , mle var
	lrtest m2
	
	* Weighted Model
	mixed vig_rating_live	i.t##($VIG) 									|| id_res: , pweight(weight) || t:  , mle var
	est store m2_w
	
	
* Model M3
mixed vig_rating_live	(i.t##($VIG))##c.weight ($RES)##c.weight 			|| id_res: 					 || t:  , mle var
	lrtest m3
	
	* Weighted Model
	xtmixed vig_rating_live	i.t##($VIG) $RES 								|| id_res: , pweight(weight) || t:  , mle var
	est store m3_w
	
	
* Model M4
mixed vig_rating_live	(i.t##($VIG)##$RES)##c.weight 						|| id_res: 					 || t:  , mle var 
	lrtest m4

	* Weighted Model
	mixed vig_rating_live	i.t##($VIG)##$RES 								|| id_res: , pweight(weight) || t:  , mle var 
	est store m4_w
	
* Compare weighted and unweighted models (not shown in the paper but see Figures generated below)
est tab m1 m1_w m2 m2_w m3 m3_w m4 m4_w, star(.05 .01 .001)	
est tab m1 m1_w m2 m2_w m3 m3_w m4 m4_w, b(%9.4f) se(%9.4f)
	
	
	
* Test for signficant change between waves in the effects of immigrant characteristics  (with weighted models)
est restore m4_w
margins res_gender, dydx($VIG) over(t) post

	
	* Immigrant's gender
		* Respondent: woman
		dis  _b[1.vig_gender:1.t#0bn.res_gender] - _b[1.vig_gender:0bn.t#0bn.res_gender]  // change in coefficients of immigrant's gender from wave 1 to wave 2
		test _b[1.vig_gender:0bn.t#0bn.res_gender] = _b[1.vig_gender:1.t#0bn.res_gender]  // change significant?
		* Respondent: man
		dis  _b[1.vig_gender:1.t#1.res_gender] - _b[1.vig_gender:0bn.t#1.res_gender]
		test _b[1.vig_gender:0bn.t#1.res_gender] = _b[1.vig_gender:1.t#1.res_gender]		
	* Immigrant's origin country = Lebanon
		* Respondent: woman
		dis  _b[0.vig_origin:1.t#0bn.res_gender] - _b[0.vig_origin:0bn.t#0bn.res_gender]
		test _b[0.vig_origin:0bn.t#0bn.res_gender] = _b[0.vig_origin:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[0.vig_origin:1.t#1.res_gender] - _b[0.vig_origin:0bn.t#1.res_gender]
		test _b[0.vig_origin:0bn.t#1.res_gender] = _b[0.vig_origin:1.t#1.res_gender]
	* Immigrant's origin country = Kenya
		* Respondent: woman
		dis  _b[2.vig_origin:1.t#0bn.res_gender] - _b[2.vig_origin:0bn.t#0bn.res_gender]
		test _b[2.vig_origin:0bn.t#0bn.res_gender] = _b[2.vig_origin:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[2.vig_origin:1.t#1.res_gender] - _b[2.vig_origin:0bn.t#1.res_gender]
		test _b[2.vig_origin:0bn.t#1.res_gender] = _b[2.vig_origin:1.t#1.res_gender]
	* Immigrant's reason for immigration = persecution
		* Respondent: woman
		dis  _b[1.vig_reason:1.t#0bn.res_gender] -  _b[1.vig_reason:0bn.t#0bn.res_gender]
		test _b[1.vig_reason:0bn.t#0bn.res_gender] = _b[1.vig_reason:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[1.vig_reason:1.t#1.res_gender] - _b[1.vig_reason:0bn.t#1.res_gender]
		test _b[1.vig_reason:0bn.t#1.res_gender] = _b[1.vig_reason:1.t#1.res_gender]
	* Immigrant's reason for immigration = job
		* Respondent: woman
		dis  _b[2.vig_reason:1.t#0bn.res_gender] - _b[2.vig_reason:0bn.t#0bn.res_gender]
		test _b[2.vig_reason:0bn.t#0bn.res_gender] = _b[2.vig_reason:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[2.vig_reason:1.t#1.res_gender] - _b[2.vig_reason:0bn.t#1.res_gender]
		test _b[2.vig_reason:0bn.t#1.res_gender] = _b[2.vig_reason:1.t#1.res_gender]	
	* Immigrant's religion = christian
		* Respondent: woman
		dis  _b[1.vig_religion:1.t#0bn.res_gender] - _b[1.vig_religion:0bn.t#0bn.res_gender]
		test _b[1.vig_religion:0bn.t#0bn.res_gender] = _b[1.vig_religion:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[1.vig_religion:1.t#1.res_gender] -  _b[1.vig_religion:0bn.t#1.res_gender]
		test _b[1.vig_religion:0bn.t#1.res_gender] = _b[1.vig_religion:1.t#1.res_gender]
	* Immigrant's religion = muslim
		* Respondent: woman
		dis  _b[2.vig_religion:1.t#0bn.res_gender] - _b[2.vig_religion:0bn.t#0bn.res_gender] 
		test _b[2.vig_religion:0bn.t#0bn.res_gender] = _b[2.vig_religion:1.t#0bn.res_gender]
		* Respondent: man
		dis  _b[2.vig_religion:1.t#1.res_gender] - _b[2.vig_religion:0bn.t#1.res_gender]
		test _b[2.vig_religion:0bn.t#1.res_gender] = _b[2.vig_religion:1.t#1.res_gender]

		
*********
* Graphs
********

* Comparing weighted and unweighted coefficients from model m2 (Figure OA1)
coefplot (m2, label("unweighted"))   (m2_w, label("weighted"))  ///
	, ytick(, nogrid) drop(_cons) xline(0, lcolor(black)) msymbol(circle) scale(0.75) aspect(0.95) yscale(lcolor(none)) ///
	yline(2.5, lcolor(gs14)) yline(4.5, lcolor(gs14)) yline(7.5, lcolor(gs14)) yline(10.5, lcolor(gs14)) ///
	yline(12.5, lcolor(gs14)) yline(14.5, lcolor(gs14)) yline(17.9, lcolor(gs14)) yline(18.1, lcolor(gs14)) ///
	yline(20.5, lcolor(gs14)) yline(23.5, lcolor(gs14)) ///
	yline(26.5, lcolor(gs14)) yline(28.5, lcolor(gs14)) yline(30.5, lcolor(gs14)) ///
	xline(-.5) ///
	scheme(s1mono) ///
		keep(1.t 1.vig_gender 0.vig_origin 2.vig_origin 1.vig_reason 2.vig_reason ///
	1.vig_qualific 1.vig_language 1.vig_religion 2.vig_religion ///
	1.t#1.vig_gender 1.t#0.vig_origin 1.t#2.vig_origin 1.t#1.vig_reason 1.t#2.vig_reason ///
	1.t#1.vig_qualific 1.t#1.vig_language 1.t#1.vig_religion 1.t#2.vig_religion) ///
		coeflabels(1.t = "t=1" 1.vig_gender = "man" 0.vig_origin1 = "Libanon" 2.vig_origin = "Kenia" ///
	1.vig_reason = "persecution" 2.vig_reason = "work"  ///
	1.vig_qualific = "high" 1.vig_language = "good" 1.vig_religion = "Christ" ///
	2.vig_religion = "Muslim" 1.t#1.vig_gender = "man" 1.t#0.vig_origin = "Libanon" 1.t#2.vig_origin = "Kenia" ///
	1.t#1.vig_reason = "persecution" 1.t#2.vig_reason = "work"  ///
	1.t#1.vig_qualific = "high" 1.t#1.vig_language = "good" 1.t#1.vig_religion = "Christ" ///
	1.t#2.vig_religion = "Muslim", labgap(-155) notick) ///
		headings(1.t = "{it:Wave (ref.: t=0)}" 1.vig_gender = "{it:Gender (ref.: woman)}" 0.vig_origin = "{it:Origin (ref.: France)}" ///
	1.vig_reason = "{it:Reason (ref.: better life)}" 1.vig_qualific = "{it:Qualification (ref.: low)}" ///
	1.vig_language = "{it:Language skills (ref.: low)}" 1.vig_religion = "{it:Religion (ref.: none)}" ///
	1.t#1.vig_gender = "{it:Gender (ref.: woman)}" 1.t#0.vig_origin = "{it:Origin (ref.: France)}" ///
	1.t#1.vig_reason = "{it:Reason (ref.: better life)}" 1.t#1.vig_qualific = "{it:Qualification (ref.: low)}" ///
	1.t#1.vig_language = "{it:Language skills (ref.: low)}" 1.t#1.vig_religion1 = "{it:Religion (ref.: none)}" , labgap(-160) nogap) ///
		groups(headroom 1.t 1.vig_gender 0.vig_origin 2.vig_origin 1.vig_reason 2.vig_reason ///
	1.vig_qualific 1.vig_language 1.vig_religion 2.vig_religion = "{bf:  Main Effects}" ///
	1.t#1.vig_gender 1.t#0.vig_origin 1.t#2.vig_origin 1.t#1.vig_reason 1.t#2.vig_reason ///
	1.t#1.vig_qualific 1.t#1.vig_language 1.t#1.vig_religion 1.t#2.vig_religion = "{bf:  Interactions (X t)}",  labgap(-55) labsize(medlarge)) ///
	name(coefficients, replace) plotr(m(zero) lpattern(blank)) graphregion(margin(l=10 r=-40)) yscale(alt) 


********************************************++
	
** Three-way interaction graph gender (Figure OA2a in online appendix)
estimates restore m4
	margins, dydx(vig_gender) over(res_gender) at(t = 0) post
		est store m4_3wayint_t0_gender
		
estimates restore m4_w
	margins, dydx(vig_gender) over(res_gender) at(t = 0) post
		est store m4_3wayint_t0_gender_w

estimates restore m4
	margins, dydx(vig_gender) over(res_gender) at(t = 1) post
		est store m4_3wayint_t1_gender

estimates restore m4_w
	margins, dydx(vig_gender) over(res_gender) at(t = 1) post
		est store m4_3wayint_t1_gender_w		
		
coefplot (m4_3wayint_t0_gender, label("Before event (t=0), unweighted") m(D) mc(gs3)) (m4_3wayint_t0_gender_w, label("Before event (t=0), weighted") m(O) mc(gs3)) ///
		 (m4_3wayint_t1_gender, label("After event (t=1), unweighted") m(D) mc(gs10)) (m4_3wayint_t1_gender_w, label("After event (t=1), weighted") m(O) mc(gs10)) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle)  ///
	title("{bf:a)} Marginal effects of male immigrant profiles (ref.: female)", span size(medsmall)) ///
	 scheme(s1mono) ///
	coeflabels(, notick) ///
	groups(headroom 0.res_gender1 1.res_gender1 = "Respondent's gender") ///
	name(threeway_int_gender, replace) plotr(m(zero) lpattern(blank))   legend(off)

** Three-way interaction graph origin (Figure OA2b in online appendix)
estimates restore m4
	margins, dydx(vig_origin) at(res_gender = 0 t = 0) post // female before
		est store m4_3wayint_origin_f_b

estimates restore m4
	margins, dydx(vig_origin) at(res_gender = 0 t = 1) post // female after
		est store m4_3wayint_origin_f_a

estimates restore m4
	margins, dydx(vig_origin) at(res_gender = 1 t = 0) post // male before
		est store m4_3wayint_origin_m_b

estimates restore m4
	margins, dydx(vig_origin) at(res_gender = 1 t = 1) post // male after
		est store m4_3wayint_origin_m_a
		
estimates restore m4_w
	margins, dydx(vig_origin) at(res_gender = 0 t = 0) post // female before
		est store m4_3wayint_origin_f_b_w

estimates restore m4_w
	margins, dydx(vig_origin) at(res_gender = 0 t = 1) post // female after
		est store m4_3wayint_origin_f_a_w

estimates restore m4_w
	margins, dydx(vig_origin) at(res_gender = 1 t = 0) post // male before
		est store m4_3wayint_origin_m_b_w

estimates restore m4_w
	margins, dydx(vig_origin) at(res_gender = 1 t = 1) post // male after
		est store m4_3wayint_origin_m_a_w
		

coefplot (m4_3wayint_origin_f_b, m(D) mc(gs3)) (m4_3wayint_origin_f_b_w, m(O) mc(gs3)) (m4_3wayint_origin_f_a, m(D) mc(gs10)) (m4_3wayint_origin_f_a_w, m(O) mc(gs10)) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle) scheme(s1mono) ///
	yline(2.5, lcolor(gs14)) coeflabels(, notick) ///
	groups(headroom 0.vig_origin1 2.vig_origin1 = "Female Respondents") 	///
	name(threeway_int_origin_female, replace) xscale(off) legend(off) plotr(m(zero) lpattern(blank))

coefplot (m4_3wayint_origin_m_b, label("Before Event (t=0), unweighted") m(D) mc(gs3)) (m4_3wayint_origin_m_b_w, label("Before Event (t=0), weighted") m(O) mc(gs3)) ///
 (m4_3wayint_origin_m_a, label("After Event (t=1), unweighted") m(D) mc(gs10)) (m4_3wayint_origin_m_a_w, label("After Event (t=1), weighted") m(O) mc(gs10)) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle) scheme(s1mono) ///
	yline(0.5, lcolor(gs14)) coeflabels(, notick) ///
	groups(headroom 0.vig_origin1 2.vig_origin1 = "Male Respondents") ///
	name(threeway_int_origin_male, replace) plotr(m(zero) lpattern(blank))  legend(off)

graph combine threeway_int_origin_female threeway_int_origin_male, title("{bf:b)} Marginal effects of immigrant profile's origin (ref.: France)", span size(medsmall)) ///
	 scheme(s1mono) xcommon col(1) imargin(t=0.9 b=0.9) iscale(1)
	

** Three-way interaction graph reason (Figure OA2c in online appendix)
estimates restore m4
	margins, dydx(vig_reason) at(res_gender = 0 t = 0) post // female before
		est store m4_3wayint_reason_f_b

estimates restore m4
	margins, dydx(vig_reason) at(res_gender = 0 t = 1) post // female after
		est store m4_3wayint_reason_f_a

estimates restore m4
	margins, dydx(vig_reason) at(res_gender = 1 t = 0) post // male before
		est store m4_3wayint_reason_m_b

estimates restore m4
	margins, dydx(vig_reason) at(res_gender = 1 t = 1) post // male after
		est store m4_3wayint_reason_m_a
		
estimates restore m4_w
	margins, dydx(vig_reason) at(res_gender = 0 t = 0) post // female before
		est store m4_3wayint_reason_f_b_w

estimates restore m4_w
	margins, dydx(vig_reason) at(res_gender = 0 t = 1) post // female after
		est store m4_3wayint_reason_f_a_w

estimates restore m4_w
	margins, dydx(vig_reason) at(res_gender = 1 t = 0) post // male before
		est store m4_3wayint_reason_m_b_w

estimates restore m4_w
	margins, dydx(vig_reason) at(res_gender = 1 t = 1) post // male after
		est store m4_3wayint_reason_m_a_w

coefplot (m4_3wayint_reason_f_b , m(D) mc(gs3)) (m4_3wayint_reason_f_b_w, m(O) mc(gs3)) ///
		 (m4_3wayint_reason_f_a , m(D) mc(gs10)) (m4_3wayint_reason_f_a_w, m(O) mc(gs10)) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle) scheme(s1mono) ///
	yline(2.5, lcolor(gs14)) coeflabels(, notick) ///
	groups(headroom 1.vig_reason1 2.vig_reason1 = "Female respondents") 	///
	name(threeway_int_reason_female, replace) xscale(off) legend(off) plotr(m(zero) lpattern(blank))

coefplot (m4_3wayint_reason_m_b, label("Wave 1 (t=0), weighted") m(D) mc(gs3)) (m4_3wayint_reason_m_b_w, label("Wave 1 (t=0), unweighted") m(O) mc(gs3)) ///
		 (m4_3wayint_reason_m_a, label("Wave 2 (t=1), weighted") m(D) mc(gs10)) (m4_3wayint_reason_m_a_w, label("Wave 2 (t=1), unweighted") m(O) mc(gs10)) ///
	, drop(_cons) xline(0, lcolor(black)) msymbol(circle) scheme(s1mono) ///
	yline(0.5, lcolor(gs14)) coeflabels(, notick) ///
	groups(headroom 1.vig_reason1 2.vig_reason1 = "Male respondents") ///
	name(threeway_int_reason_male, replace) plotr(m(zero) lpattern(blank)) 

graph combine threeway_int_reason_female threeway_int_reason_male, title("{bf:c)} Marginal effects of immigrant profile's reason of migration (ref.: better life)", span size(medsmall)) ///
	 scheme(s1mono) xcommon col(1) imargin(t=0.9 b=0.9) iscale(.8)
	
****************************************+	
	
log close
